@@ -10,7 +10,7 @@ use Class::Params qw(params);
 # Definition.
 my $self = {};
 my $def_hr = {
-        'par' => ['par', 'SCALAR', 1],
+        'par' => ['_par', undef, 'SCALAR', 1],
 };
 
 # Check.
